@@ -129,6 +129,7 @@ typedef struct {
 
 	GList               *categories_list;
 	GList               *delete_list;
+	GList               *saved_images_list;
 
 	/**/
 
@@ -136,6 +137,8 @@ typedef struct {
 	guint                check_id;
 	GMutex              *yes_or_no;
 	gboolean             thread_done; 
+
+	guint                idle_id;
 } DialogData;
 
 
@@ -154,6 +157,11 @@ destroy_cb (GtkWidget  *widget,
 		data->check_id = 0;
 	}
 
+	if (data->idle_id != 0) {
+		g_source_remove (data->idle_id);	
+		data->idle_id = 0;
+	}
+
 	/**/
 
 	g_mutex_lock (data->yes_or_no);
@@ -182,6 +190,7 @@ destroy_cb (GtkWidget  *widget,
 		g_object_unref (data->camera_present_pixbuf);
 	path_list_free (data->categories_list);
 	path_list_free (data->delete_list);
+	path_list_free (data->saved_images_list);
 	gp_camera_unref (data->camera);
 	gp_context_unref (data->context);
 	gp_abilities_list_free (data->abilities_list);
@@ -251,17 +260,33 @@ ctx_progress_update_func (GPContext    *context,
 
 
 static gboolean
-valid_mime_type (const char *type)
+valid_mime_type (const char *name,
+		 const char *type)
 {
-	const char *mime_types[] = { "image",
-				     "video",
-				     "audio" };
-	int i;
+	int         i;
+	const char *name_ext;
 
-	for (i = 0; i < G_N_ELEMENTS (mime_types); i++) {
-		const char *mime_type = mime_types[i];
-		if (strncasecmp (type, mime_type, strlen (mime_type)) == 0)
-			return TRUE;
+	if ((type != NULL) && (strcmp (type, "") != 0)) {
+		const char *mime_types[] = { "image",
+					     "video",
+					     "audio" };
+		for (i = 0; i < G_N_ELEMENTS (mime_types); i++) {
+			const char *mime_type = mime_types[i];
+			if (strncasecmp (type, mime_type, strlen (mime_type)) == 0)
+				return TRUE;
+		}
+	}	
+	
+	name_ext = get_filename_extension (name);
+	if ((name_ext != NULL) && (strcmp (name_ext, "") != 0)) {
+		const char *exts[] = { "JPG", "JPEG", "PNG", "TIF", "TIFF", "GIF",
+				       "AVI", "MPG", "MPEG", 
+				       "AU", "WAV", "OGG", "MP3", "FLAC" };
+		for (i = 0; i < G_N_ELEMENTS (exts); i++) {
+			const char *ext = exts[i];
+			if (strncasecmp (ext, name_ext, strlen (name_ext)) == 0)
+				return TRUE;
+		}
 	}
 
 	return FALSE;
@@ -289,9 +314,14 @@ get_file_list (DialogData *data,
 			CameraFileInfo  info;
 
 			gp_list_get_name (list, i, &name);
-			gp_camera_file_get_info (data->camera, folder, name, &info, data->context);
+			if (gp_camera_file_get_info (data->camera, 
+						     folder, 
+						     name, 
+						     &info, 
+						     NULL) != GP_OK)
+				continue;
 			
-			if (valid_mime_type (info.file.type)) {
+			if (valid_mime_type (info.file.name, info.file.type)) {
 				char *filename = g_build_filename (folder, name, NULL);
 				file_list = g_list_prepend (file_list, filename);
 			}
@@ -1165,8 +1195,8 @@ save_image (DialogData *data,
 
 	if (gp_file_save (file, local_path) >= 0) {
 		if (data->delete_from_camera) 
-			data->delete_list = g_list_prepend (data->delete_list, 
-							    g_strdup (camera_path));
+			data->delete_list = g_list_prepend (data->delete_list, g_strdup (camera_path));
+		data->saved_images_list = g_list_prepend (data->saved_images_list, g_strdup (camera_path));
 		add_categories_to_image (data, local_path);
 	} else {
 		g_mutex_lock (data->yes_or_no);
@@ -1245,7 +1275,17 @@ static void
 save_images__init (AsyncOperationData *aodata, 
 		   DialogData         *data)
 {
+	all_windows_remove_monitor ();
+
 	data->image_n = 1;
+	if (data->delete_list != NULL) {
+		path_list_free (data->delete_list);
+		data->delete_list = NULL;
+	}
+	if (data->saved_images_list != NULL) {
+		path_list_free (data->saved_images_list);
+		data->saved_images_list = NULL;
+	}
 }
 
 
@@ -1258,6 +1298,26 @@ save_images__step (AsyncOperationData *aodata,
 }
 
 
+static gboolean
+notify_cb (gpointer cb_data)
+{
+	DialogData *data = cb_data;
+
+	g_source_remove (data->idle_id);
+	data->idle_id = 0;
+
+	if (data->saved_images_list != NULL) {
+		all_windows_notify_files_created (data->saved_images_list);
+		path_list_free (data->saved_images_list);
+		data->saved_images_list = NULL;
+	}
+	
+	all_windows_add_monitor ();
+
+	return FALSE;
+}
+
+
 static void 
 save_images__done (AsyncOperationData *aodata, 
 		   DialogData         *data)
@@ -1271,6 +1331,8 @@ save_images__done (AsyncOperationData *aodata,
 	error = data->error;
 	g_mutex_unlock (data->yes_or_no);
 
+	data->idle_id = g_idle_add (notify_cb, data);
+
 	if (interrupted || error)
 		return;
 
@@ -1409,13 +1471,13 @@ ok_clicked_cb (GtkButton  *button,
 
 		camera_folder = remove_level_from_path (camera_path);
 		camera_filename = file_name_from_path (camera_path);
-		gp_camera_file_get_info (data->camera, 
-					 camera_folder, 
-					 camera_filename,
-					 &info,
-					 data->context);
+		if (gp_camera_file_get_info (data->camera, 
+					     camera_folder, 
+					     camera_filename,
+					     &info,
+					     NULL) == GP_OK)
+			total_size += (GnomeVFSFileSize) info.file.size;
 		g_free (camera_folder);
-		total_size += (GnomeVFSFileSize) info.file.size;
 	}
 
 	if (get_dest_free_space (data->local_folder) < total_size) {
@@ -1662,6 +1724,7 @@ dlg_photo_importer (GThumbWindow *window)
 
 	data->yes_or_no = g_mutex_new ();
 	data->check_id = 0;
+	data->idle_id = 0;
 	data->msg_text  = NULL;
 
 	/* Get the widgets. */
